==> FHLBBS-4.1.tgz: wbbs/login.c <==
#include "cgic.h"
#include "wbbs.c"
char *crypt();


int cgiMain() {
    char userid[IDLEN+1];
    char password[PASSLEN+PASSLEN+1];
    char *key;
	int uid,fh;
    char cotest[256],genbuf[256];
    int gotomode; //mode=0 `login  =1 Ѥplogini
    FILE *fp;
    char remotehost[16],remoteuser[8];
    char *pt1,*pt2;
    int ptmode;

    strncpy(remotehost,cgiRemoteHost,15);    
    if (remotehost[0]==0)
      strncpy(remotehost,cgiRemoteAddr,15); 
    strncpy(remoteuser,cgiRemoteUser,7);
    remoteuser[7]=0;
    remotehost[15]=0;
    cgiFormStringNoNewlines("submit1",genbuf,32);
    if (strstr(genbuf,"U"))
    {
	cgiHeaderLocation("fileout.cgi?regster");
    }
    if (strstr(genbuf,"X"))
    {
	strcpy(userid,"guest");
    } else
    {
      	cgiFormStringNoNewlines("USERNAME",userid,IDLEN);
    	cgiFormStringNoNewlines("PASSWORD",password,PASSLEN);
    } 
    cgiFormInteger("GOTO",&gotomode,0);
        
    if (!(uid = searchuser(userid))){
       set_idcookie(0,userid,"");
       cgiHeaderContentType("text/html");
       fprintf(cgiOut,"BBS user %s not existed<p>\n", userid);
       return -1;
    }
    if ((fh = get_userec(uid, &cuser)) == -1){
       set_idcookie(0,userid,"");
       cgiHeaderContentType("text/html");
       fprintf(cgiOut,"KXŪɿ~<p>\n");
       return -1;
    } 
        
  	key = crypt(password, cuser.passwd);

    /* cgiHeaderContentType("text/html");
    fprintf(cgiOut," userid=%sI<p>\n", userid);
    fprintf(cgiOut," password=%sI<p>\n", password);
    fprintf(cgiOut," cuser.passwd=%sI<p>\n", cuser.passwd);
    fprintf(cgiOut," key=%sI<p>\n", key);
    return -1;  */

  	if ((strcmp(key, cuser.passwd))&&(strcmp(userid,"guest")))
  	{
  	  set_idcookie(0,userid,"");
          cgiHeaderContentType("text/html");
    	fprintf(cgiOut," %s KX~I<p>\n", userid);
	if (gotomode) fprintf(cgiOut,"<a href=\"%s\">",LOGINWIN);
	else fprintf(cgiOut,"<a href=\"%s\">",MAINLOGIN);
	fprintf(cgiOut,"ЫBsnJ</a><p>\n");
    	return -1;
  	}
	/*** nJ\ ***/
  	set_idcookie(1,userid,cuser.passwd);
	/********  OU ************/
        sprintf(genbuf,"%4d  %s@%s",1,remoteuser,remotehost); 
        log_usies("ENTER", genbuf);
        cgiHeaderContentType("text/html");
	cuser.lastlogin=time(0);
	cuser.numlogins=cuser.numlogins+1;
	strcpy(cuser.lasthost,remotehost);
	strcpy(cuser.remoteuser,remoteuser);
	if(substitute_record(fn_passwd, &cuser, sizeof(cuser), uid) == -1) 
	{
          fprintf(cgiOut," register lastlogin fail!!!\n");
          fprintf(cgiOut,"</font>\n");
          fprintf(cgiOut,"</body></html>\n");
          exit(0);
        }
	//resolve_ucache();
        setuserid(uid, cuser.userid);
	//sethomepath(genbuf, cuser.userid);
    //    mkdir(genbuf, 0755);
        if (gotomode)
  	   {
	     if ((fp=fopen(DEFDIR FHLWELCOME,"r"))==NULL)
	     {
	      fprintf(cgiOut,"<h1>HRwzI</h1>");
		  return(0);
	     }
	   }
	   else
	   {
          if ((fp=fopen(DEFDIR MAINFUNC,"r"))==NULL)
          {
            fprintf(cgiOut,"<h1>D\\}ҿ~I</h1><p>\n");
            return(0);
          }
	   }
        while (fgets(genbuf,255,fp))
        {
          pt1=genbuf;
          while (pt2=strstr(pt1,"<!--$"))
          {
           *pt2=0;
           pt2=pt2+5;
           fprintf(cgiOut,"%s", pt1);/* LXtokener */
           pt1=strstr(pt2,"-->");
           if (pt1==NULL) 
           {
              fprintf(cgiOut,"榡ɿ~IP@椺䤣 -->");
              return 0;
           }
           *pt1=0;
           pt1=pt1+3;
           ptmode=atoi(pt2);
           if (ptmode)   SSI(ptmode);
          }
           fprintf(cgiOut,"%s",pt1);
        }
        fclose(fp);
        return 0;
}

==> FHLBBS-4.2.tgz: wbbs/login.c <==
#include "cgic.h"
#include "wbbs.c"
char *crypt();


int cgiMain() {
    char userid[IDLEN+1];
    char password[PASSLEN+PASSLEN+1];
    char *key;
    int uid,fh;
    char cotest[256],genbuf[256],ppath[128];
    int gotomode; //mode=0 `login  =1 Ѥplogini
    FILE *fp;
    char remotehost[16],remoteuser[8];
    char *pt1,*pt2,*pt;
    int ptmode,fd,len;
    char fname[128];
    time_t now;

    strncpy(remotehost,cgiRemoteHost,15);    
    if (remotehost[0]==0)
      strncpy(remotehost,cgiRemoteAddr,15); 
    strncpy(remoteuser,cgiRemoteUser,7);
    remoteuser[7]=0;
    remotehost[15]=0;
    cgiFormStringNoNewlines("submit1",genbuf,32);
    if (strstr(genbuf,"U"))
    {
	cgiHeaderLocation("fileout.cgi?regster");
    }
    if (strstr(genbuf,"X"))
    {
	strcpy(userid,"guest");
    } else
    {
      	cgiFormStringNoNewlines("USERNAME",userid,IDLEN);
    	cgiFormStringNoNewlines("PASSWORD",password,PASSLEN);
    } 
    cgiFormInteger("GOTO",&gotomode,0);
        
    if (!(uid = searchuser(userid))){
       set_idcookie(0,userid,"");
       cgiHeaderContentType("text/html");
       fprintf(cgiOut,"BBS user %s not existed<p>\n", userid);
       return -1;
    }
    if ((fh = get_userec(uid, &cuser)) == -1){
       set_idcookie(0,userid,"");
       cgiHeaderContentType("text/html");
       fprintf(cgiOut,"KXŪɿ~<p>\n");
       return -1;
    } 
        
  	key = crypt(password, cuser.passwd);

    /* cgiHeaderContentType("text/html");
    fprintf(cgiOut," userid=%sI<p>\n", userid);
    fprintf(cgiOut," password=%sI<p>\n", password);
    fprintf(cgiOut," cuser.passwd=%sI<p>\n", cuser.passwd);
    fprintf(cgiOut," key=%sI<p>\n", key);
    return -1;  */

  	if ((strcmp(key, cuser.passwd))&&(strcmp(userid,"guest")))
  	{
  	  set_idcookie(0,userid,"");
          cgiHeaderContentType("text/html");
    	fprintf(cgiOut," %s KX~I<p>\n", userid);
      /**** ~login***/
       now=time(0);
       sprintf(genbuf, "[%s] %s\n", Cdate(&now), remotehost);
       len = strlen(genbuf);
       sethomefile(fname, userid, "logins.bad");
       if ((fd = open(fname, O_WRONLY | O_CREAT | O_APPEND, 0644)) > 0)
        {
            write(fd, genbuf, len);
            close(fd);
        }
	if (gotomode) fprintf(cgiOut,"<a href=\"%s\">",LOGINWIN);
	else fprintf(cgiOut,"<a href=\"%s\">",MAINLOGIN);
	fprintf(cgiOut,"ЫBsnJ</a><p>\n");
    	return -1;
  	}
	/*** nJ\ ***/
       /******** ocookie **********/
      if (getenv("HTTP_COOKIE"))
    	{
      	strncpy(cook_buf,getenv("HTTP_COOKIE"),255);
      	cook_buf[255]=0;
    	} 	else  cook_buf[0]=0;
  	if (cook_buf[0])
  	{
    /**** extract password and username****/
    	pt=strstr(cook_buf,"loginpath=");
	cotest[0]=0;
    	if (pt) 
    	{
        /*** Xjs ***/ 
	genbuf[0]=*(pt+10);
	genbuf[1]=0;
	doorid=atoi(genbuf);
	strcpy(cotest,pt+77);
	pt=pt+20;//Lloginpath=Mɶ
    /****** XQװϽs ***/
    	strncpy(genbuf,pt,5);
	genbuf[5]=0;
	Cookiebnumout=atoi(genbuf);
	pt=pt+5;
	/****** X峹s ****/
	strncpy(genbuf,pt,8);
	genbuf[8]=0;
	Cookienumout=atoi(genbuf);
	pt=pt+8;
	/**** XQװϦW ****/
        strncpy(genbuf,pt,IDLEN);
	genbuf[IDLEN]=0;
	sscanf(genbuf,"%s",Cboardout);
	} //pt
	} //Cookie
	    /******* username **************/
  	set_idcookie(1,userid,cuser.passwd);
	/********  OU ************/
        sprintf(genbuf,"%4d  %s@%s",1,remoteuser,remotehost); 
        log_usies("ENTER", genbuf);
        cgiHeaderContentType("text/html");
	cuser.lastlogin=time(0);
	cuser.numlogins=cuser.numlogins+1;
	strcpy(cuser.lasthost,remotehost);
	strcpy(cuser.remoteuser,remoteuser);
	if(substitute_record(fn_passwd, &cuser, sizeof(cuser), uid) == -1) 
	{
          fprintf(cgiOut," register lastlogin fail!!!\n");
          fprintf(cgiOut,"</font>\n");
          fprintf(cgiOut,"</body></html>\n");
          exit(0);
        }
	//resolve_ucache();
        setuserid(uid, cuser.userid);
	//sethomepath(genbuf, cuser.userid);
    //    mkdir(genbuf, 0755);
        if (gotomode)
  	   {
	     if ((fp=fopen(DEFDIR FHLWELCOME,"r"))==NULL)
	     {
	      fprintf(cgiOut,"<h1>HRwzI</h1>");
		  return(0);
	     }
	   }
	   else
	   {
          if ((fp=fopen(DEFDIR MAINFUNC,"r"))==NULL)
          {
            fprintf(cgiOut,"<h1>D\\}ҿ~I</h1><p>\n");
            return(0);
          }
	   }
        while (fgets(genbuf,255,fp))
        {
          pt1=genbuf;
          while (pt2=strstr(pt1,"<!--$"))
          {
           *pt2=0;
           pt2=pt2+5;
           fprintf(cgiOut,"%s", pt1);/* LXtokener */
           pt1=strstr(pt2,"-->");
           if (pt1==NULL) 
           {
              fprintf(cgiOut,"榡ɿ~IP@椺䤣 -->");
              return 0;
           }
           *pt1=0;
           pt1=pt1+3;
           ptmode=atoi(pt2);
           if (ptmode)   SSI(ptmode);
	   else
	   {
		if (cotest[0])
		{
		   sscanf(cotest,"%s",ppath);
		   fprintf(cgiOut,"%s",ppath);
		}
		else fprintf(cgiOut,"/cgi-bin/boards.cgi?sysop");
	   }
          }
           fprintf(cgiOut,"%s",pt1);
        }
        fclose(fp);
        return 0;
}
